/* AMPPZ 2005, Zadanie Jaskinie, rozwiazanie wzorcowe
   Autor: Kamil Kloch
*/
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <math.h>

#define MAX_N 1700

int V_Match[MAX_N], W_Match[MAX_N];        	// skojarzenie pamietane w obie strony
int V_LayerNum[MAX_N], W_LayerNum[MAX_N];  	// numer warstwy danego wierzcholka
int V_InDegree[MAX_N], W_InDegree[MAX_N];	// liczba kraw. wchodz. do wierzch. w Hungarian Tree
int V_InTree[MAX_N], W_InTree[MAX_N];		// czy dany wierzcholek jest w Hungarian Tree
int Unmatched[MAX_N];				// wolne wierzcholki w ostatniej parzystej warstwie
int LayerSize[2*MAX_N+1];			// liczba wierzch. przynaleznych do danej warstwy
int VerticesByLayers[2*MAX_N];			// wierzcholki ulozone wg warstw
char G[MAX_N][MAX_N];                     	// graf okreslajaych poset, (przechodnim domk.) 
int i, j, n, numCases, numMatches;
int numLayeredVertices; 			// liczba wierzcholkow wlozonych do ktorejs z warstw
int numUnmatched;				// liczba wierzcholkow wolnych w prawej warstwie
int numChains;					// liczba lancuchow pokrywajacych poset


inline void AddVertexToLayer(int n, int layerNum) {
    VerticesByLayers[numLayeredVertices++] = n;
    LayerSize[layerNum]++;
    if (layerNum & 1) // odd(layerNum)
	V_LayerNum[n] = layerNum;
    else {
	W_LayerNum[n] = layerNum;
	if (W_Match[n] == -1) // wolny wierzcholek
	    Unmatched[numUnmatched++] = n;
    }	
}

void KillDeadVertex(int v, int layerNum) {
    // wywala wierzcholek z Hungarian Tree, 
    // zmniejsza InDegree sasiadow , potem ew. wywoluje sie rekurencyjnie
    if (layerNum > W_LayerNum[VerticesByLayers[numLayeredVertices-1]])
	return;
    if (layerNum & 1) {
	// lewa warstwa
	if (!V_InTree[v])
	    return;
	V_InTree[v] = 0;
	V_InDegree[v] = 0;
	for (int i=0; i<n; i++)
	    if (G[v][i] && W_InTree[i] && (W_LayerNum[i] == layerNum+1)) {
		// zmniejszami InDegree i ew. wywolujemy sie rekurencyjnie
		W_InDegree[i]--;
		if (!W_InDegree[i])
		    KillDeadVertex(i, layerNum+1);
	    }
    }
    else {
	// prawa warstwa
	if (!W_InTree[v])
	    return;
	W_InTree[v] = 0;
	W_InDegree[v] = 0;
	KillDeadVertex(W_Match[v], layerNum+1);
    }
}

void DFS_Ubij_Drzewo(int v, int prev_v, int layerNum) {
    /*	rekurencyjne znajdowanie pojedynczej sciezki alternujacej
	+ usuwanie martwych wierzcholkow z Hungarian Tree
    */
    KillDeadVertex(v, layerNum); //usuwanie ew. martwych wierzcholkow
    if (layerNum & 1) {
	// lewa warstwa
	if (layerNum > 1)
	    DFS_Ubij_Drzewo(V_Match[v], v, layerNum-1);

	V_Match[v] = prev_v; // zmiana skojarzenia
	W_Match[prev_v] = v;
    }
    else {
	// prawa warstwa
	for (int i=0; i<n; i++)
	    if (G[i][v] && V_InTree[i] && (V_LayerNum[i] == layerNum-1)) {
		DFS_Ubij_Drzewo(i, v, layerNum-1);
		break;
	    }
    }
}

void debug() {
    for(int i=0; i<n-1; i++)
	printf("%d ", V_Match[i]+1);
    printf("%d\n", V_Match[n-1]+1);
    for(int i=0; i<n-1; i++)
	printf("%d ", W_Match[i]+1);
    printf("%d\n\n", W_Match[n-1]+1);
}


int HopcroftKarpMatching() {
    /*	funkcja zwraca wielkosc naliczniejszego skojarzenia w grafie dwudzielnym V+W;
	maksymalne skojarzenie zapisane jest w tablicy `V_Match'
    */

    int i, j, currLayer;
    numMatches = 0;
    for (i=0; i<n; i++)
	V_Match[i] = W_Match[i] = -1;
    // greedy initial maximal matching
    for (i=0; i<n; i++)
	for (j=0; j<n; j++)
	    if(G[i][j] && (W_Match[j] == -1)) {
		V_Match[i] = j;
		W_Match[j] = i;
		numMatches++;
		break;
	    }
    //debug();

    while (1) {
	// warstwy numerujemy od 1, 0 oznacza brak przynaleznosci
	numLayeredVertices = 0;
	memset(V_LayerNum, 0, n*sizeof(int));
	memset(W_LayerNum, 0, n*sizeof(int));
	memset(LayerSize, 0, (2*n+1)*sizeof(int));
	for (i=0; i<n; i++)
	    if (V_Match[i] == -1) // i jest wolnym wierzcholkiem
		AddVertexToLayer(i, 1);
	currLayer = 1;
	while (1) {
	    /* 	dopoki istnieja wierzcholki w warstwie po lewej stronie
		stworz nowa (prawa) warstwe z wszystkich niewykorzystanych dotad wierzcholkow
	       polaczonych jakakolwiek krawedzia z wierzcholkami z lewej (aktualnej) warstwy
	    */
	    numUnmatched = 0;  // liczba znalezionych wolnych wierzcholkow
	    int i = numLayeredVertices - 1;
	    for (int j=i; j>i-LayerSize[currLayer]; j--) {
		// przegladamy wszystkie wierzcholki lewej warstwy
		int v = VerticesByLayers[j];
		for (int k=0; k<n; k++)
		    if ( G[v][k] && !W_LayerNum[k])
			AddVertexToLayer(k, currLayer+1);
	    }
	    // prawa warstwa (o numerze `currLayer+1') utworzona
	    currLayer++; 	// aktual warstwa to teraz warstwa prawa

	    if (!LayerSize[currLayer]) {
		// nie istnieje sciezka alternujaca zwiekszjaca skojarzenie
		return numMatches;
	    }
	    if (numUnmatched) // znalezione wolne wierzcholki
		break;

	    i = numLayeredVertices - 1;
	    for (int j=i; j>i-LayerSize[currLayer]; j--) {
		// przegladamy wszystkie wierzcholki z prawej warstwy
		AddVertexToLayer(W_Match[VerticesByLayers[j]], currLayer+1);
	    }
	    currLayer++;
	}
	/*  currLayer to prawa warstwa, w ktorej znaleziono wolne wierzcholki
	    znajduja sie one w tablicy `Unmatched[0..numUnmatched-1]'
	    tworzymy teraz Hungarian Tree, skladajace sie z wszystkich krawedzi laczacych wierzcholki
	    dwoch sasiadujacych warstw
	*/
	memset(V_InDegree, 0, n*sizeof(int));
	memset(W_InDegree, 0, n*sizeof(int));
	memset(V_InTree, 0, n*sizeof(int));
	memset(W_InTree, 0, n*sizeof(int));
	int nextLayer, actLayer = 1;
	int nextLayerOffset, actLayerOffset = 0;
	while (actLayer < currLayer) {
	    // wszystkie warstwy oprocz ostatniej
	    nextLayer = actLayer + 1;
	    nextLayerOffset = actLayerOffset + LayerSize[actLayer];
	    if (actLayer & 1) {
		// lewa warstwa
		for (int i=actLayerOffset; i<actLayerOffset+LayerSize[actLayer]; i++) {
		    int v = VerticesByLayers[i];
		    V_InTree[v] = 1;
		    for (int j=nextLayerOffset; j<nextLayerOffset+LayerSize[nextLayer]; j++) {
			int w = VerticesByLayers[j];
			if (G[v][w]) {
			    // dodajemy do Hungariam Tree krawedz (v,w)
			    W_InDegree[w]++;
			}
		    }
		}
	    }
	    else {
		// prawa warstwa
		for (int i=actLayerOffset; i<actLayerOffset+LayerSize[actLayer]; i++) {
		    int w = VerticesByLayers[i];
		    W_InTree[w] = 1;
		    int v = W_Match[w];
		    V_InDegree[v]++;
		}
	    }
	    actLayer = nextLayer;
	    actLayerOffset = nextLayerOffset;
	}
	for (int i=numLayeredVertices-1; i>=numLayeredVertices-LayerSize[currLayer]; i--)
	    W_InTree[VerticesByLayers[i]] = (W_Match[VerticesByLayers[i]] == -1);

	// mamy wyliczone tablice `V_InDegree' i `W_InDegree', `V_InTree', `W_InTree'
	for (int i=0; i<numUnmatched; i++)
	    if(W_InTree[Unmatched[i]]) {
		DFS_Ubij_Drzewo(Unmatched[i], -1, currLayer);
		numMatches++;
	    }
    }
}

int main() {
    scanf("%d\n", &numCases);
    char s[MAX_N+10];
    while (numCases--) {
	scanf("%d\n", &n);
	for (i=0; i<n; i++) {
	    fgets(s, n+5, stdin);
	    for(j=0; j<n; j++) {
		G[i][j] = (s[j] == '1');	
		//printf("%d ", G[i][j]);
	    }
	    //printf("\n");
	    
	}
	
	numChains = n - HopcroftKarpMatching();
	printf("%d\n", numChains);
	
	/*
	for(i=0; i<n-1; i++)
	    printf("%d ", V_Match[i]);
	printf("%d\n", V_Match[n-1]);
	for(i=0; i<n-1; i++)
	    printf("%d ", W_Match[i]);
	printf("%d\n\n", W_Match[n-1]);
	*/
	
	for (i=0; i<n; i++)
	    if (V_Match[i]>-2) {
		// idziemy w gore lancucha...
		j = i;
		while (W_Match[j]>=0) 
		    j = W_Match[j];
		// j jest najwiekszym el. w lancuchu
		do {
		    int k = V_Match[j];
		    V_Match[j] = -2;
		    if (k>=0)
			printf("%d ", j+1);
		    else
			printf("%d\n", j+1);	
		    j = k;		    
		} while (j>=0);
	    }
    }
    return 0;
}
